# coding: utf-8

"""
EventApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class EventApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_event_event(self, event_event_id, **kwargs):
        """
        
        Retrieve event information.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_event_event(event_event_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str event_event_id: Retrieve event information. (required)
        :return: EventEvents
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['event_event_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_event_event" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'event_event_id' is set
        if ('event_event_id' not in params) or (params['event_event_id'] is None):
            raise ValueError("Missing the required parameter `event_event_id` when calling `get_event_event`")


        resource_path = '/platform/2/event/events/{EventEventId}'.replace('{format}', 'json')
        path_params = {}
        if 'event_event_id' in params:
            path_params['EventEventId'] = params['event_event_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['basic_auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='EventEvents',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_event_events(self, **kwargs):
        """
        
        Retrieve event information.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_event_events(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool count: If true, return a count of events.
        :param str sort: The field that will be used for sorting.
        :param int begin: Specifies the earliest time to query events from.
        :param int end: Specifies the latest time to query events from.
        :param list[int] event_type: Specifies the event_id of events to query for.
        :param bool coalesced: If true, only return events that have been coalesced.
        :param str resume: Continue returning results from previous call using this token (token should come from the previous call, resume cannot be used with other options).
        :param list[str] devid: Specifies the devid of events to query for.
        :param bool acknowledged: If true, only return events that have been acknowledged.
        :param bool ended: If true, only return events that have ended.
        :param int limit: Return no more than this many results at once (see resume).
        :param str dir: The direction of the sort.
        :param bool coalescing: If true, only return coalescing events.
        :param list[str] severity: Specifies the severity of events to query for.
        :return: EventEventsExtended
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['count', 'sort', 'begin', 'end', 'event_type', 'coalesced', 'resume', 'devid', 'acknowledged', 'ended', 'limit', 'dir', 'coalescing', 'severity']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_event_events" % key
                )
            params[key] = val
        del params['kwargs']


        if 'limit' in params and params['limit'] < 1.0: 
            raise ValueError("Invalid value for parameter `limit` when calling `get_event_events`, must be a value greater than or equal to `1.0`")

        resource_path = '/platform/2/event/events'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'count' in params:
            query_params['count'] = params['count']
        if 'sort' in params:
            query_params['sort'] = params['sort']
        if 'begin' in params:
            query_params['begin'] = params['begin']
        if 'end' in params:
            query_params['end'] = params['end']
        if 'event_type' in params:
            query_params['event_type'] = params['event_type']
        if 'coalesced' in params:
            query_params['coalesced'] = params['coalesced']
        if 'resume' in params:
            query_params['resume'] = params['resume']
        if 'devid' in params:
            query_params['devid'] = params['devid']
        if 'acknowledged' in params:
            query_params['acknowledged'] = params['acknowledged']
        if 'ended' in params:
            query_params['ended'] = params['ended']
        if 'limit' in params:
            query_params['limit'] = params['limit']
        if 'dir' in params:
            query_params['dir'] = params['dir']
        if 'coalescing' in params:
            query_params['coalescing'] = params['coalescing']
        if 'severity' in params:
            query_params['severity'] = params['severity']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['basic_auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='EventEventsExtended',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
